arena_results: Test Dataset with Arena Results

Description Usage Format

Description

A dataset containing test data from an Arena simulation model

Usage

1

Format

A data frame with 2280 rows and 4 variables:

Scenario

The Scenario Name

Statistic

The Statistic's description

Replication

The Replication Number

Value

The numeric value of the statistic within the replication and scenario


pedroliman/arena2r documentation built on May 9, 2019, 5:57 a.m.