Learn R Programming

arena2r (version 1.0.0)

arena_results: Test Dataset with Arena Results

Description

A dataset containing test data from an Arena simulation model

Usage

arena_results

Arguments

Format

A data frame with 2280 rows and 4 variables:

Scenario

The Scenario Name

Statistic

The Statistic's description

Replication

The Replication Number

Value

The numeric value of the statistic within the replication and scenario